%global py3_incdir %(python3 -c 'import distutils.sysconfig; print(distutils.sysconfig.get_python_inc())')
%global py3_libbuilddir %(python3 -c 'import sys; import sysconfig; print("lib.{p}-cpython-{v[0]}{v[1]}".format(p=sysconfig.get_platform(), v=sys.version_info))')

%global pypi_name pillow
%global srcname   Pillow

%bcond_with docs

Name:           python-%{pypi_name}
Version:        11.1.0
Release:        %mkrel 1
Summary:        Python image processing library

Group:          Development/Python
# License: see http://www.pythonware.com/products/pil/license.htm
License:        MIT
URL:            https://python-pillow.github.io/
Source0:        https://github.com/python-pillow/Pillow/archive/%{version}/Pillow-%{version}.tar.gz

Patch0:         Pillow-fix-linking.patch
# When building docs, error occurs: ModuleNotFoundError: No module named 'PIL', it needs to be found
Patch2:         Pillow-10.2.0-allow-docs-build-without-module-installation.patch

BuildRequires:  pkgconfig(tk)
BuildRequires:  pkgconfig(libjpeg)
BuildRequires:  pkgconfig(libopenjp2)
BuildRequires:  pkgconfig(imagequant)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(lcms2)
BuildRequires:  ghostscript
BuildRequires:  pkgconfig(libwebp)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  python3-devel
BuildRequires:  python3-cffi
BuildRequires:  python3-olefile
BuildRequires:  python3-pytest
# for patch2
BuildRequires:  git-core

# For EpsImagePlugin.py
Requires:       ghostscript

Provides:       python-imaging = %{version}-%{release}

%description
Python image processing library, fork of the Python Imaging Library (PIL)

This library provides extensive file format support, an efficient
internal representation, and powerful image processing capabilities.

There are four subpackages: tk (tk interface), qt (PIL image wrapper for Qt),
devel (development) and doc (documentation).

%package -n python3-%{pypi_name}
Group:          Development/Python
Summary:        Python 3 image processing library
Provides:       python3-imaging = %{version}-%{release}
Provides:       python3dist(PIL) = %{version}-%{release}

%description -n python3-%{pypi_name}
Python image processing library, fork of the Python Imaging Library (PIL)

This library provides extensive file format support, an efficient
internal representation, and powerful image processing capabilities.

There are four subpackages: tk (tk interface), qt (PIL image wrapper for Qt),
devel (development) and doc (documentation).

%package -n python3-%{pypi_name}-devel
Summary:        Development files for python3-%{pypi_name}
Group:          Development/C
Requires:       python3-%{pypi_name} = %{version}-%{release}
Requires:       python3-devel
Requires:       libjpeg-devel
Requires:       zlib-devel

%description -n python3-%{pypi_name}-devel
Development files for python3-%{pypi_name}.

%package -n python3-%{pypi_name}-doc
Summary:        Documentation for python3-%{pypi_name}
Group:          Documentation
Requires:       python3-%{pypi_name} = %{version}-%{release}
BuildArch:      noarch

%description -n python3-%{pypi_name}-doc
Documentation for python3-%{pypi_name}.

%package -n python3-%{pypi_name}-tk
Summary:        Tk interface for python3-%{pypi_name}
Group:          System/Libraries
Requires:       python3-%{pypi_name} = %{version}-%{release}
Requires:       python3-tkinter

%description -n python3-%{pypi_name}-tk
Tk interface for python3-%{pypi_name}.

%package -n python3-%{pypi_name}-qt
Summary:        PIL image wrapper for Qt
Group:          System/Libraries
Requires:       python3-%{pypi_name} = %{version}-%{release}
Requires:       python3-qt5

%description -n python3-%{pypi_name}-qt
PIL image wrapper for Qt.

%prep
%autosetup -p1 -n Pillow-%{version}

# drop bundled egg-info
rm -rf src/*.egg-info/

# Don't error out if sphinx warnings occur
sed -ie "s/--fail-on-warning //" docs/Makefile

%generate_buildrequires
%pyproject_buildrequires %{?with_docs:-x docs}

%build
%pyproject_wheel

%if %{with docs}
#for docs
PYTHONPATH=$PWD/build/%py3_libbuilddir:$PWD/docs make -C docs html BUILDDIR=_build SPHINXBUILD=sphinx-build-%python3_version
rm -f docs/_build/html/.buildinfo
%endif

%install
# Install Python 3 modules
install -d %{buildroot}/%{py3_incdir}/Imaging
install -m 644 src/libImaging/*.h %{buildroot}/%{py3_incdir}/Imaging
%pyproject_install


%check
# Check Python 3 modules
ln -s $PWD/Images $PWD/build/%py3_libbuilddir/Images
cp -R $PWD/Tests $PWD/build/%py3_libbuilddir/Tests
cp -a $PWD/selftest.py $PWD/build/%py3_libbuilddir/selftest.py
pushd build/%py3_libbuilddir
PYTHONPATH=$PWD %{__python3} selftest.py
popd
%pytest -v -k "not test_qt_image_qapplication"

%files -n python3-%{pypi_name}
%doc README.md CHANGES.rst
%license docs/COPYING
%{python3_sitearch}/PIL/
%{python3_sitearch}/pillow-%{version}.dist-info
# These are in subpackages
%exclude %{python3_sitearch}/PIL/_imagingtk*
%exclude %{python3_sitearch}/PIL/ImageTk*
%exclude %{python3_sitearch}/PIL/SpiderImagePlugin*
%exclude %{python3_sitearch}/PIL/ImageQt*
%exclude %{python3_sitearch}/PIL/__pycache__/ImageTk*
%exclude %{python3_sitearch}/PIL/__pycache__/SpiderImagePlugin*
%exclude %{python3_sitearch}/PIL/__pycache__/ImageQt*

%files -n python3-%{pypi_name}-devel
%{py3_incdir}/Imaging/
%if %{with docs}
%doc docs/_build/html
%endif

%files -n python3-%{pypi_name}-tk
%{python3_sitearch}/PIL/_imagingtk*
%{python3_sitearch}/PIL/ImageTk*
%{python3_sitearch}/PIL/SpiderImagePlugin*
%{python3_sitearch}/PIL/__pycache__/ImageTk*
%{python3_sitearch}/PIL/__pycache__/SpiderImagePlugin*

%files -n python3-%{pypi_name}-qt
%{python3_sitearch}/PIL/ImageQt*
%{python3_sitearch}/PIL/__pycache__/ImageQt*


%changelog
* Sat Feb 22 2025 wally <wally> 11.1.0-1.mga10
+ Revision: 2150720
- new version 11.1.0
- rebuild for python3.13 without docs

* Tue Aug 20 2024 papoteur <papoteur> 10.4.0-1.mga10
+ Revision: 2087148
- new version 10.4.0
- add PYTHONPATH for building docs, to use custom dater.py

* Tue Apr 09 2024 papoteur <papoteur> 10.3.0-1.mga10
+ Revision: 2056185
- new version 10.3.0

* Fri Jan 26 2024 papoteur <papoteur> 10.2.0-1.mga10
+ Revision: 2035239
- new version 10.2.0

* Sat Dec 09 2023 wally <wally> 10.0.1-3.mga10
+ Revision: 2016077
- rebuild for py3.12

* Fri Oct 13 2023 daviddavid <daviddavid> 10.0.1-2.mga10
+ Revision: 1995542
- fix arm linking issue

* Fri Oct 13 2023 daviddavid <daviddavid> 10.0.1-1.mga10
+ Revision: 1995535
- new version: 10.0.1

* Wed Dec 14 2022 daviddavid <daviddavid> 9.2.0-3.mga9
+ Revision: 1922146
- rebuild for new libtiff in Core/Release

* Mon Dec 12 2022 ns80 <ns80> 9.2.0-2.mga9
+ Revision: 1921101
- rebuild for new libtiff

* Sat Aug 20 2022 papoteur <papoteur> 9.2.0-1.mga9
+ Revision: 1878845
- new 9.2.0
- add BR for furo theme
- fix module import for documentation building

* Fri May 06 2022 papoteur <papoteur> 9.1.0-1.mga9
+ Revision: 1856464
- Update to 9.1.0

* Wed Apr 06 2022 umeabot <umeabot> 8.3.2-6.mga9
+ Revision: 1845931
- Mageia 9 Mass Rebuild

* Mon Feb 14 2022 tv <tv> 8.3.2-5.mga9
+ Revision: 1774916
+ rebuild (emptylog)

* Mon Feb 14 2022 joequant <joequant> 8.3.2-4.mga9
+ Revision: 1774449
- update to python 3.10
+ tmb <tmb>
- rebuild for python 3.10
+ tv <tv>
- Rebuild for python-3.10

* Wed Sep 22 2021 neoclust <neoclust> 8.3.2-1.mga9
+ Revision: 1746196
- New version 8.3.2: Fixes CVE-2021-23437 (mga#29481)

* Sun Aug 29 2021 wally <wally> 8.3.1-1.mga9
+ Revision: 1743482
- new version 8.3.1
- sync with Fedora where appropriate

* Sun Aug 01 2021 neoclust <neoclust> 8.1.2-2.mga9
+ Revision: 1738429
- Add P105: Fixes CVE-2021-34552 (mga#29002)
- Add P104: Fixes CVE-2021-28678 (mga#29002)
- Add P103: Fixes CVE-2021-28677 (mga#29002)
- Add P101: Fixes CVE-2021-28676 (mga#29002)
- Add P101: Fixes CVE-2021-28675 (mga#29002)
- Add P100: Fixes CVE-2021-25287,CVE-2021-25288 (mga#29002)

* Sun Mar 21 2021 guillomovitch <guillomovitch> 8.1.2-1.mga9
+ Revision: 1707173
- new version 8.1.2

* Mon Mar 15 2021 neoclust <neoclust> 8.1.0-3.mga9
+ Revision: 1703164
- Rebuild against python 3.9

* Sun Jan 24 2021 daviddavid <daviddavid> 8.1.0-2.mga8
+ Revision: 1673190
- add upstream patch to Handle PCX images with an odd stride
  * fix for nml build failure

* Sun Jan 17 2021 neoclust <neoclust> 8.1.0-1.mga8
+ Revision: 1672245
- New version  8.1.0 (mga#28137)

* Sun Nov 08 2020 guillomovitch <guillomovitch> 8.0.1-1.mga8
+ Revision: 1643739
- new version 8.0.1
- drop mentions of sane subpackage, that doesn't exist anymore

* Tue Sep 08 2020 guillomovitch <guillomovitch> 7.2.0-1.mga8
+ Revision: 1623666
- new version 7.2.0

* Tue Apr 28 2020 daviddavid <daviddavid> 7.1.2-1.mga8
+ Revision: 1572825
- new version: 7.1.2

* Sat Apr 04 2020 daviddavid <daviddavid> 7.1.1-1.mga8
+ Revision: 1564255
- new version: 7.1.1

* Thu Feb 20 2020 umeabot <umeabot> 7.0.0-2.mga8
+ Revision: 1546105
- Mageia 8 Mass Rebuild

* Fri Jan 31 2020 daviddavid <daviddavid> 7.0.0-1.mga8
+ Revision: 1485933
- new version: 7.0.0

* Thu Jan 16 2020 shlomif <shlomif> 6.2.2-1.mga8
+ Revision: 1478164
- New version 6.2.2 - MGA#25968

* Mon Dec 23 2019 shlomif <shlomif> 6.2.1-2.mga8
+ Revision: 1469736
- Add a provides for "PIL".

* Wed Nov 13 2019 daviddavid <daviddavid> 6.2.1-1.mga8
+ Revision: 1459724
- new version: 6.2.1

* Thu Oct 10 2019 daviddavid <daviddavid> 6.2.0-1.mga8
+ Revision: 1450908
- new version: 6.2.0
+ wally <wally>
- add patch to fix linking
- drop python2 leftover BRs

* Fri Sep 13 2019 tv <tv> 6.1.0-2.mga8
+ Revision: 1440544
- "fix" underlinking
- drop BR on python-numpy
- drop BR on python-setuptools
- rebuild for python-3.8
- drop python2 subpkg

* Sat Aug 24 2019 wally <wally> 6.1.0-1.mga8
+ Revision: 1431788
- new version 6.1.0
- update doc build
- build with libimagequant and openjpeg

* Fri Jan 11 2019 kekepower <kekepower> 5.4.1-1.mga7
+ Revision: 1354964
- Update to version 5.4.1

* Sat Jan 05 2019 wally <wally> 5.3.0-2.mga7
+ Revision: 1349857
- rebuild for python3.7

* Fri Dec 28 2018 luigiwalser <luigiwalser> 5.3.0-1.mga7
+ Revision: 1345815
- 5.3.0

* Sun Sep 23 2018 umeabot <umeabot> 4.3.0-4.mga7
+ Revision: 1300545
- Mageia 7 Mass Rebuild

* Sun Apr 29 2018 joequant <joequant> 4.3.0-3.mga7
+ Revision: 1223473
- regenerate rpms

* Fri Apr 27 2018 luigiwalser <luigiwalser> 4.3.0-2.mga7
+ Revision: 1222745
- obsolete wrongly imported python-pil

* Mon Oct 16 2017 joequant <joequant> 4.3.0-1.mga7
+ Revision: 1172291
- upgrade to 4.3.0

* Thu Aug 03 2017 philippem <philippem> 4.2.1-1.mga7
+ Revision: 1134296
- update to 4.2.1

* Wed Oct 26 2016 luigiwalser <luigiwalser> 3.4.2-1.mga6
+ Revision: 1063598
- 3.4.2

* Wed Oct 12 2016 philippem <philippem> 3.4.1-1.mga6
+ Revision: 1060512
- update to 3.4.1

* Sun Apr 10 2016 philippem <philippem> 3.2.0-1.mga6
+ Revision: 1000067
- update to 3.2.0

* Mon Feb 08 2016 philippem <philippem> 3.1.1-1.mga6
+ Revision: 948936
- update to 3.1.1 (fix CVE-2016-2533, CVE-2016-0775, CVE-2016-0740)

* Thu Feb 04 2016 philippem <philippem> 3.1.0-2.mga6
+ Revision: 936143
- fix buffer overflow mga#17671

* Thu Jan 21 2016 daviddavid <daviddavid> 3.1.0-1.mga6
+ Revision: 926206
- new version: 3.1.0

* Sat Jan 02 2016 luigiwalser <luigiwalser> 3.0.0-4.mga6
+ Revision: 918205
- rebuild for libwebp

* Fri Oct 23 2015 luigiwalser <luigiwalser> 3.0.0-3.mga6
+ Revision: 894647
- add conflicts to fix upgrade for mga#16975

* Mon Oct 19 2015 philippem <philippem> 3.0.0-2.mga6
+ Revision: 892704
- Some Bytecode files were in the wrong rpm

* Sat Oct 10 2015 philippem <philippem> 3.0.0-1.mga6
+ Revision: 889373
- update to 3.0.0

* Thu Oct 08 2015 daviddavid <daviddavid> 2.9.0-2.mga6
+ Revision: 887342
- rebuild for python 3.5
- rebuild for tcl/tk 8.6.4

* Fri Aug 28 2015 philippem <philippem> 2.9.0-1.mga6
+ Revision: 870452
- update to 2.9.0, move python-sane in a new package

* Mon Mar 02 2015 luigiwalser <luigiwalser> 2.6.2-2.mga5
+ Revision: 817289
- bump release tag to fix upgrade from mga4 (mga#15392)

* Sat Jan 24 2015 philippem <philippem> 2.6.2-1.mga5
+ Revision: 812146
- Update to 2.6.2, security fix mga#15115

* Wed Oct 15 2014 umeabot <umeabot> 2.5.3-4.mga5
+ Revision: 750439
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 2.5.3-3.mga5
+ Revision: 726908
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 2.5.3-2.mga5
+ Revision: 688215
- Mageia 5 Mass Rebuild

* Thu Aug 21 2014 luigiwalser <luigiwalser> 2.5.3-1.mga5
+ Revision: 666105
- Update to 2.5.3 (Fix CVE-2014-3598, a DOS in the Jpeg2KImagePlugin)

* Fri Aug 15 2014 philippem <philippem> 2.5.2-1.mga5
+ Revision: 662700
- Update to 2.5.2 (Fix CVE-2014-3589, a DOS in the IcnsImagePlugin)

* Mon Aug 11 2014 philippem <philippem> 2.5.1-1.mga5
+ Revision: 661679
- update to 2.5.1

* Thu Jul 03 2014 philippem <philippem> 2.5.0-1.mga5
+ Revision: 642788
- update to 2.5.0

* Sun Jun 01 2014 pterjan <pterjan> 2.4.0-0.2.mga5
+ Revision: 630390
- Soften python3 dependency
- Rebuild for new Python
+ daviddavid <daviddavid>
- fix description on main python3-pillow package

* Fri Apr 04 2014 philippem <philippem> 2.4.0-0.1.mga5
+ Revision: 611707
- update to 2.4.0

* Sun Mar 23 2014 luigiwalser <luigiwalser> 2.3.1-0.1.mga5
+ Revision: 606963
- 2.3.1 (fixes CVE-2014-1932 and CVE-2014-1933)

* Sat Feb 15 2014 luigiwalser <luigiwalser> 2.3.0-0.1.mga5
+ Revision: 592373
- update to 2.3.0 (sync with fedora)
- change lcms BR to lcms2
- add patches from fedora (including one to fix a test)
- add missing ghostscript Requires and BuildRequires (from fedora)
- add upstream patch to fix build with freetype 2.5
- rebuild for libwebp

* Tue Oct 22 2013 umeabot <umeabot> 2.2.1-0.3.mga4
+ Revision: 544030
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 2.2.1-0.2.mga4
+ Revision: 499118
- Rebuild to add different pythonegg provides for python 2 and 3

* Fri Oct 04 2013 philippem <philippem> 2.2.1-0.1.mga4
+ Revision: 491495
- Update to 2.2.1

* Sat Sep 07 2013 philippem <philippem> 2.1.0-0.2.mga4
+ Revision: 475735
- Add patch to fix memory corruption caused by invalid palette size, mga#10729

* Mon Jul 08 2013 philippem <philippem> 2.1.0-0.1.mga4
+ Revision: 451502
- Update to 2.1.0
- Update to 2.1.0

* Wed Jul 03 2013 philippem <philippem> 2.0.0-0.gitd1c6db8.4.mga4
+ Revision: 449875
- obsolete old PIL

* Mon Jul 01 2013 philippem <philippem> 2.0.0-0.gitd1c6db8.3.mga4
+ Revision: 448886
+ rebuild (emptylog)

* Sat Jun 29 2013 philippem <philippem> 2.0.0-0.gitd1c6db8.2.mga4
+ Revision: 448390
- add provides

* Sat Jun 29 2013 philippem <philippem> 2.0.0-0.gitd1c6db8.1.mga4
+ Revision: 448268
- fix groups
- add Python3
- add missing BR
- imported package python-pillow

